{% extends "base.html" %}
{% block main_sidebar %}
{% endblock %}
{% block content_header %}
    <div class="callout callout-warning">
    <ul>
        <li><h4>No one project on scrapyd found. Please upload it and refresh the page after a while</h4></li>
    </ul>
</div>
{% endblock %}
{% block content_body %}
{% endblock %}